#define TRUE 			1
#define FALSE 			0


typedef struct {
		char	input_dir[255],
			input_file[100],
			edi1_dir[255],
			edi1_file[100],
			edi2_dir[255],
			edi2_file[100],
			edi3_dir[255],
			edi3_file[100],
			edi4_dir[255],
			edi4_file[100],

			eig_TeX[30],

			Edit_font[200];

		int	i_previewer,
			i_dpi,
			i_resolution,
			i_leaves,
			i_begin_pageno,
			i_end_pageno,
			i_shrink_factor,
			eig_dpi;

		int	document_Vorlage;

		float	x_home,
			y_home;

		int	TeXlanguage,
			TeXformat,
			TeXrun;

		int	breite,
			hoehe;
			
		int	printresolution,
			printlanguage,
			printdevice;
		Boolean	BiBTeX,
			MakeIndex,
			OddPages,
			EvenPages;	} TeXshell_DATA;

