
static TeXshell_DATA	defaults =
	{	/* input_dir*/		"",
		/* input_file*/		"",
		/* edi1_dir*/		"",
		/* edi1_file*/		"",
		/* edi2_dir*/		"",
		/* edi2_file*/		"",
		/* edi3_dir*/		"",
		/* edi3_file*/		"",
		/* edi4_dir*/		"",
		/* edi4_file*/		"",

		/* eig_TeX*/		"ifmtex",
		/* Edit_font*/		"/usr/openwin/lib/fonts/6x12",

		/* i_previewer*/	1,
		/* i_dpi*/		300,
		/* i_resolution*/	3,
		/* i_leaves*/		1,
		/* i_begin_pageno*/	1,
		/* i_end_pageno*/	1000,
		/* i_shrink_factor*/	3,
		/* eig_dpi*/		0,

		/* document_Vorlage*/	0,

		/* x_home*/		31.75,
		/* y_home*/		41.91,

		/* TeXlanguage*/	0,
		/* TeXformat*/		0,
		/* TeXrun*/		0,

		/* breite*/		640,
		/* hoehe*/		200,

		/* printresolution*/	0,
		/* printlanguage*/	0,
		/* printdevice*/	0,
		/* BiBTeX*/		FALSE,
		/* MakeIndex*/		FALSE,
		/* OddPages*/		TRUE,
		/* EvenPages*/		TRUE		};

TeXshell_DATA	actual,out;

